from __future__ import absolute_import
from trashtalk.trash import Trash
from trashtalk.core import trashtalk
from trashtalk.autocomplete_bash import autocomplete

__version__ = '0.0.6.1'

__all__ = ['__version__', 'Trash', 'trashtalk']
